// Flutter Packages
import 'package:flutter/material.dart';

// Data Models
import '../models/view_type.dart';

// Widgets
import 'grid_pagination.dart';
import 'list_pagination.dart';
import 'wrap_pagination.dart';

class BuildPagination extends StatelessWidget {
  const BuildPagination({
    Key? key,
    this.viewType = ViewType.list,
    required this.controller,
    required this.items,
    required this.itemBuilder,
    required this.isLoading,
  }) : super(key: key);

  final ViewType viewType;
  final ScrollController controller;
  final List<dynamic> items;
  final Widget Function(BuildContext, dynamic, int) itemBuilder;
  final bool isLoading;

  @override
  Widget build(BuildContext context) {
    switch (viewType) {
      case ViewType.list:
        return ListPagination(
          controller: controller,
          items: items,
          itemBuilder: itemBuilder,
          isLoading: isLoading,
        );
      case ViewType.grid:
        return GridPagination(
          controller: controller,
          items: items,
          itemBuilder: itemBuilder,
          isLoading: isLoading,
        );
      case ViewType.wrap:
        return WrapPagination(
          controller: controller,
          items: items,
          itemBuilder: itemBuilder,
          isLoading: isLoading,
        );
    }
  }
}
