// Flutter Packages
import 'package:flutter/material.dart';

class GridPagination<T> extends StatelessWidget {
  const GridPagination({
    Key? key,
    required this.controller,
    required this.items,
    required this.itemBuilder,
    required this.isLoading,
    this.gridDelegate = const SliverGridDelegateWithFixedCrossAxisCount(
      crossAxisCount: 2,
      childAspectRatio: 1,
    ),
  }) : super(key: key);

  final ScrollController controller;
  final List<T> items;
  final Widget Function(BuildContext, T, int) itemBuilder;
  final bool isLoading;
  final SliverGridDelegate gridDelegate;

  @override
  Widget build(BuildContext context) {
    return GridView.builder(
      controller: controller,
      itemCount: items.length + (isLoading ? 1 : 0),
      itemBuilder: (BuildContext context, int index) {
        if (index >= items.length) {
          return const Center(child: CircularProgressIndicator.adaptive());
        }
        return itemBuilder(context, items[index], index);
      },
      gridDelegate: gridDelegate,
    );
  }
}
